==> gs2-cdk-1.0.9.tar.gz: gs2-cdk-1.0.9/src/gs2_cdk/quest/model/CurrentMasterData.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import CdkResource, Stack
from .QuestGroupModel import QuestGroupModel


class CurrentMasterData(CdkResource):
    version: str= "2019-05-14"
    namespace_name: str
    quest_group_models: List[QuestGroupModel]

    def __init__(
        self,
        stack: Stack,
        namespace_name: str,
        quest_group_models: List[QuestGroupModel],
    ):
        super().__init__(
            "Quest_CurrentQuestMaster_" + namespace_name
        )

        self.namespace_name = namespace_name
        self.quest_group_models = quest_group_models
        stack.add_resource(
            self,
        )

    def alternate_keys(
        self,
    ):
        return self.namespace_name

    def resource_type(
        self,
    ) -> str:
        return "GS2::Quest::CurrentQuestMaster"

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}
        settings: Dict[str, Any] = {}

        settings["version"] = self.version
        if self.quest_group_models is not None:
            settings["questGroupModels"] = [
                v.properties(
                )
                for v in self.quest_group_models
            ]

        if self.namespace_name is not None:
            properties["NamespaceName"] = self.namespace_name
        if settings is not None:
            properties["Settings"] = settings

        return properties

==> gs2-cdk-1.0.94.tar.gz: gs2-cdk-1.0.94/src/gs2_cdk/quest/model/CurrentMasterData.py <==
# Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
# Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License").
# You may not use this file except in compliance with the License.
# A copy of the License is located at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
# or in the "license" file accompanying this file. This file is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
# express or implied. See the License for the specific language governing
# permissions and limitations under the License.
from __future__ import annotations
from typing import *

from ...core.model import CdkResource, Stack
from .QuestGroupModel import QuestGroupModel


class CurrentMasterData(CdkResource):
    version: str= "2019-05-14"
    namespace_name: str
    groups: List[QuestGroupModel]

    def __init__(
        self,
        stack: Stack,
        namespace_name: str,
        groups: List[QuestGroupModel],
    ):
        super().__init__(
            "Quest_CurrentQuestMaster_" + namespace_name
        )

        self.namespace_name = namespace_name
        self.groups = groups
        stack.add_resource(
            self,
        )

    def alternate_keys(
        self,
    ):
        return self.namespace_name

    def resource_type(
        self,
    ) -> str:
        return "GS2::Quest::CurrentQuestMaster"

    def properties(
        self,
    ) -> Dict[str, Any]:
        properties: Dict[str, Any] = {}
        settings: Dict[str, Any] = {}

        settings["version"] = self.version
        if self.groups is not None:
            settings["groups"] = [
                v.properties(
                )
                for v in self.groups
            ]

        if self.namespace_name is not None:
            properties["NamespaceName"] = self.namespace_name
        if settings is not None:
            properties["Settings"] = settings

        return properties
